/** 
 *   Thermometer TC6003P
 *
 *   (c) Copyright 2005 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

#define _GNU_SOURCE


#include <stdio.h>
#include <getopt.h>
#include "thermometer.h"
#include "my_stdio.h"



int main(int argc, char * const argv[])
{
	int fd;
	int op;
	double temperature;
	char *device = THERMOMETER_DEVICE;

#ifdef VERBOSE_MODE
	verbose_flag = PERR;
#endif
	while  ((op = getopt(argc, argv, "vhd:")) != EOF)
		switch( op ){
#ifdef VERBOSE_MODE
		case 'v':
			verbose_flag = (verbose_flag << 1) | 1;
			break;
#endif
		case 'd':
			device = optarg;
			break;
		case 'h':
		default:
			printf("Use %s [-v (incremental)] [-h] [-d device (def: %s)]\n", 
			       argv[0], THERMOMETER_DEVICE);
			exit(-1);
		}
	
	if ((fd = thermometer_open(device)) < 0) {
		perror("Thermometer open");
		return -1;
	}	
	if (thermometer_get(fd, &temperature) == 0) {
		printf("Temperature: %5.1f\n", temperature);
	}
	thermometer_close(fd);

	return 0;
}
